Gleam HTTP

Types and functions for HTTP clients and servers!

Server adapters

Server adapters can be used to run Gleam HTTP services written using this package. Here’s a full list of the servers and adapters available, sorted alphabetically.

AdapterAbout
cgiCgi is a adapter for the Common Gateway Interface.
fcgiCgi is a adapter for the Fast Common Gateway Interface.
eweEwe is a Gleam HTTP2 & HTTP1.1 web server
gleam_cowboyCowboy is an Erlang HTTP2 & HTTP1.1 web server
gleam_elliElli is an Erlang HTTP1.1 web server
mistMist is a Gleam HTTP1.1 server

Client adapters

Client adapters are used to send HTTP requests to services over the network. Here’s a full list of the client adapters available, sorted alphabetically.

AdapterAbout
gleam_fetchfetch is a HTTP client included with JavaScript
gleam_hackneyHackney is a simple HTTP client for Erlang
gleam_httpchttpc is a HTTP client included with Erlang
Search Document